pub struct ObservabilityConfig {
pub trace_llm_calls: bool,
pub log_full_prompts: bool,
pub log_full_responses: bool,
pub track_token_usage: bool,
pub trace_memory_access: bool,
pub enable_context_snapshots: bool,
pub capture_reasoning_traces: bool,
pub max_content_length: usize,
pub model_name: Option<String>,
pub cost_per_1m_input: Option<f64>,
pub cost_per_1m_output: Option<f64>,
}Expand description
Observability configuration for the runner
Fields
trace_llm_calls: boolEnable LLM call tracing (start/end/failed events)
log_full_prompts: boolLog full prompts (expensive - use for debugging only)
log_full_responses: boolLog full responses (expensive - use for debugging only)
track_token_usage: boolTrack token usage and emit token.usage events
trace_memory_access: boolTrace memory access (recall/store events)
enable_context_snapshots: boolEnable context window snapshots
capture_reasoning_traces: boolEnable reasoning trace capture
max_content_length: usizeMaximum content length for logged prompts/responses
model_name: Option<String>Model name for cost calculation (optional)
cost_per_1m_input: Option<f64>Cost per 1M input tokens (USD) from provider config If set, overrides hardcoded model pricing
cost_per_1m_output: Option<f64>Cost per 1M output tokens (USD) from provider config If set, overrides hardcoded model pricing